@@ -40,7 +40,9 @@ __all__ = ["check_dict"]
 import numpy as np
 import pandas as pd
 
-VALID_INDEX_TYPES = (pd.Int64Index, pd.RangeIndex, pd.PeriodIndex, pd.DatetimeIndex)
+from sktime.utils.validation.series import is_in_valid_index_types
+
+VALID_INDEX_TYPES = (pd.RangeIndex, pd.PeriodIndex, pd.DatetimeIndex)
 
 # whether the checks insist on freq attribute is set
 FREQ_SET_CHECK = False
@@ -69,10 +71,10 @@ def check_pddataframe_series(obj, return_metadata=False, var_name="obj"):
     metadata["is_univariate"] = len(obj.columns) < 2
 
     # check whether the time index is of valid type
-    if not type(index) in VALID_INDEX_TYPES:
+    if not is_in_valid_index_types(index):
         msg = (
             f"{type(index)} is not supported for {var_name}, use "
-            f"one of {VALID_INDEX_TYPES} instead."
+            f"one of {VALID_INDEX_TYPES} or integer index instead."
         )
         return ret(False, msg, None, return_metadata)
 
@@ -131,10 +133,10 @@ def check_pdseries_series(obj, return_metadata=False, var_name="obj"):
         return ret(False, msg, None, return_metadata)
 
     # check whether the time index is of valid type
-    if not type(index) in VALID_INDEX_TYPES:
+    if not is_in_valid_index_types(index):
         msg = (
             f"{type(index)} is not supported for {var_name}, use "
-            f"one of {VALID_INDEX_TYPES} instead."
+            f"one of {VALID_INDEX_TYPES} or integer index instead."
         )
         return ret(False, msg, None, return_metadata)
 
@@ -214,8 +216,8 @@ def _index_equally_spaced(index):
     -------
     equally_spaced: bool - whether index is equally spaced
     """
-    if not isinstance(index, VALID_INDEX_TYPES):
-        raise TypeError(f"index must be one of {VALID_INDEX_TYPES}")
+    if not is_in_valid_index_types(index):
+        raise TypeError(f"index must be one of {VALID_INDEX_TYPES} or integer index")
 
     # empty and single element indices are equally spaced
     if len(index) < 2:
