@@ -83,9 +83,9 @@ class BaseFixtureGenerator:
     Fixtures parameterized
     ----------------------
     estimator_class: estimator inheriting from BaseObject
-        ranges over all estimator classes not excluded by EXCLUDED_TESTS
+        ranges over estimator classes not excluded by EXCLUDE_ESTIMATORS, EXCLUDED_TESTS
     estimator_instance: instance of estimator inheriting from BaseObject
-        ranges over all estimator classes not excluded by EXCLUDED_TESTS
+        ranges over estimator classes not excluded by EXCLUDE_ESTIMATORS, EXCLUDED_TESTS
         instances are generated by create_test_instance class method
     scenario: instance of TestScenario
         ranges over all scenarios returned by retrieve_scenarios
@@ -121,6 +121,7 @@ class BaseFixtureGenerator:
             fixture_vars=fixture_vars,
             generator_dict=self.generator_dict(),
             fixture_sequence=fixture_sequence,
+            raise_exceptions=True,
         )
 
         metafunc.parametrize(fixture_param_str, fixture_prod, ids=fixture_names)
@@ -280,7 +281,7 @@ class QuickTester:
         Parameters
         ----------
         estimator : estimator class or estimator instance
-        return_exception : bool, optional, default=True
+        return_exceptions : bool, optional, default=True
             whether to return exceptions/failures, or raise them
                 if True: returns exceptions in results
                 if False: raises exceptions as they occur
@@ -381,6 +382,8 @@ class QuickTester:
             fixture_vars = getfullargspec(test_fun)[0][1:]
             fixture_vars = [var for var in fixture_sequence if var in fixture_vars]
 
+            raise_exceptions = not return_exceptions
+
             # this call retrieves the conditional fixtures
             #  for the test test_name, and the estimator
             _, fixture_prod, fixture_names = create_conditional_fixtures_and_names(
@@ -388,6 +391,7 @@ class QuickTester:
                 fixture_vars=fixture_vars,
                 generator_dict=temp_generator_dict,
                 fixture_sequence=fixture_sequence,
+                raise_exceptions=raise_exceptions,
             )
 
             # if function is decorated with mark.parameterize, add variable settings
