@@ -14,12 +14,11 @@ import pandas as pd
 from joblib import Parallel, delayed
 from numba import njit
 
-from sktime.datatypes._panel._convert import from_nested_to_3d_numpy
-from sktime.transformations.base import _PanelToTabularTransformer
-from sktime.utils.validation.panel import check_X
+from sktime.datatypes import convert_to
+from sktime.transformations.base import BaseTransformer
 
 
-class Catch22(_PanelToTabularTransformer):
+class Catch22(BaseTransformer):
     """Canonical Time-series Characteristics (catch22).
 
     Overview: Input n series with d dimensions of length m
@@ -45,11 +44,22 @@ class Catch22(_PanelToTabularTransformer):
     Journal of the Royal Society Interface, 10(83), 20130048.
     """
 
+    _tags = {
+        "scitype:transform-input": "Series",
+        # what is the scitype of X: Series, or Panel
+        "scitype:transform-output": "Primitives",
+        # what is the scitype of y: None (not needed), Primitives, Series, Panel
+        "scitype:instancewise": True,  # is this an instance-wise transform?
+        "X_inner_mtype": "numpy3D",  # which mtypes do _fit/_predict support for X?
+        "y_inner_mtype": "None",  # which mtypes do _fit/_predict support for y?
+        "fit_is_empty": True,
+    }
+
     def __init__(
         self,
         outlier_norm=False,
         replace_nans=False,
-        n_jobs=1,
+        n_jobs=-1,
     ):
         self.outlier_norm = outlier_norm
         self.replace_nans = replace_nans
@@ -69,28 +79,29 @@ class Catch22(_PanelToTabularTransformer):
 
         super(Catch22, self).__init__()
 
-    def transform(self, X, y=None):
+    def _transform(self, X, y=None):
         """Transform data into the catch22 features.
 
         Parameters
         ----------
-        X : pandas DataFrame or 3d numpy array, input time series.
+        X : 3d numpy array, input time series panel.
         y : array_like, target values (optional, ignored).
 
         Returns
         -------
         Pandas dataframe containing 22 features for each input series.
         """
-        self.check_is_fitted()
-        X = check_X(X, enforce_univariate=False, coerce_to_numpy=True)
         n_instances = X.shape[0]
 
-        c22_list = Parallel(n_jobs=self.n_jobs)(
-            delayed(self._transform_case)(
-                X[i],
+        if self.n_jobs == -1:
+            c22_list = [self._transform_case(X[i]) for i in range(n_instances)]
+        else:
+            c22_list = Parallel(n_jobs=self.n_jobs)(
+                delayed(self._transform_case)(
+                    X[i],
+                )
+                for i in range(n_instances)
             )
-            for i in range(n_instances)
-        )
 
         if self.replace_nans:
             c22_list = np.nan_to_num(c22_list, False, 0, 0, 0)
@@ -150,7 +161,8 @@ class Catch22(_PanelToTabularTransformer):
 
         Parameters
         ----------
-        X : pandas DataFrame, input time series. Currently univariate only.
+        X : np.ndarray, 3D, in numpy3D mtype format
+            or other sktime data container of Panel scitype
         feature : int, catch22 feature id or String, catch22 feature
                   name.
         case_id : int, identifier for the current set of cases. If the case_id is not
@@ -175,7 +187,7 @@ class Catch22(_PanelToTabularTransformer):
             raise ValueError("catch22 feature name or ID required")
 
         if isinstance(X, pd.DataFrame):
-            X = from_nested_to_3d_numpy(X)
+            X = convert_to(X, "numpy3D")
 
         if len(X.shape) > 2:
             n_instances, n_dims, series_length = X.shape
